<h1 align="center">Pebble 🐧</h1>

<h1 align="center">Agent-to-Agent Communication </h1>

[![GitHub License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/badge/python-3.12+-blue.svg)](https://www.python.org/downloads/)
[![Discord](https://img.shields.io/discord/bgwYGs7t?color=7289DA&label=Discord&logo=discord&logoColor=white)](https://discord.gg/bgwYGs7t)
[![Documentation](https://img.shields.io/badge/Documentation-📕-blue)](https://docs.pebbling.ai)

🪨 Pebble is the easiest way to enable seamless, secure communication between autonomous AI agents.

💡 Built on **JSON-RPC 2.0** over **mutual TLS (mTLS)**, Pebble provides a lightweight yet powerful protocol framework for the next generation of collaborative AI systems.


## Contributing

Please do contribute.

We provide a developer version with additional pre-commit hooks to perform checks compared to the official version:

# For mac
uv add pebble --dev

# Install pre-commit hooks
pre-commit install
